# reducss
Reduce CSS size with Python

## Install
```
pip install reducss
```

## Usage
### Quick start
```python3
import reducss
reducss.auto(dirname="./")
```

## License
This project is under the MIT-License.  
See also [LICENSE](LICENSE).

## Author
Laddge
